/*
 * Copyright (C) 2023  Valentin Lorentz
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

mod room;
pub use room::RoomBuffer;

pub trait Buffer {
  /// A short human-readable name for the room, eg. to show in compact buflist
  fn short_name(&self) -> String;
}

pub struct Buffers(Vec<Box<dyn Buffer>>);

impl Buffers {
  pub fn new() -> Self {
    Self(Vec::new())
  }

  pub fn iter(&self) -> impl Iterator<Item = &dyn Buffer> {
    self.0.iter().map(|buffer_box| &**buffer_box)
  }

  pub fn push(&mut self, buffer: Box<dyn Buffer>) {
    self.0.push(buffer)
  }
}
